MII Implementierungsleitfaden Kerndatensatz-Modul Molekulargenetischer Befundbericht
2027.0.0-ballot.1 -
Germany
This page is part of the MII IG Kerndatensatz-Modul Molekulargenetischer Befundbericht (v2027.0.0-ballot.1: Release) based on FHIR (HL7® FHIR® Standard) R4. This is the current published version in its permanent home (it will always be available at this URL). For a full list of available versions, see the Directory of published versions
Language: de
Bundle mii-exa-molgen-bundle-fam-his-breast-ovar-can of type transaction
Entry 1 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-patient-brca1
Resource Patient:
Language: de
Elisa Schmidt-Huber (official) Female, DoB: 1973-03-12 ( Medical record number (use: usual, ))
Deceased: false Other Id: Gesetzliche Krankenversicherung/Z977188448 (use: official, ) Contact Detail Anna-Louisa-Karsch Str. 2 Berlin DE-BE 10178 DE
Request:
PUT Patient/mii-exa-molgen-patient-brca1
Entry 2 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-befundbericht-trurisk-panel
Resource DiagnosticReport:
Language: de
Profiles: MII PR MolGen Molekulargenetischer Befundbericht version: 2027.0.0-ballot.1, Genomic Report version: 3.0.0
Genetic analysis report (Genetics)
Subject Elisa Schmidt-Huber (official) Female, DoB: 1973-03-12 ( Medical record number (use: usual, )) Performer Practitioner Dr. Daniel Schmidt(official) Report Details
Code Value Flags Relevant Time Genetic variant assessment Present Final 2022-11-01 Diagnostic Implication Final 2022-11-01 Nachweis heterozygoter Sequenzveränderung, die zum Funktionsverlust führt.
Request:
PUT DiagnosticReport/mii-exa-molgen-befundbericht-trurisk-panel
Entry 3 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-folgemassnahme-brca1
Resource Task:
Language: de
Profiles: MII PR MolGen Empfohlene Folgemaßnahme version: 2027.0.0-ballot.1, Followup Recommendation version: 3.0.0
basedOn: ServiceRequest Molecular genetic test (procedure)
status: Requested
intent: Proposal
code: Genetic counseling recommended
description: Eine genetische Beratung hinsichtlich einer gezielten Testung leiblicher Familienmitglieder wird empfohlen.
for: Elisa Schmidt-Huber (official) Female, DoB: 1973-03-12 ( Medical record number (use: usual, ))
Request:
PUT Task/mii-exa-molgen-folgemassnahme-brca1
Entry 4 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-prs-brca1
Resource RiskAssessment:
Language: de
Profile: MII PR MolGen Polygener Risiko Score version: 2027.0.0-ballot.1
status: Final
subject: Melanie Marie Müller (official) Female, DoB: 2021-09-19 ( Medical record number (use: usual, ))
occurrence: 2022-11-01
basis: Observation Genetic variant assessment
Predictions
Extension Outcome QualitativeRisk Hereditary breast and ovarian cancer syndrome (disorder) High likelihood
Request:
PUT RiskAssessment/mii-exa-molgen-prs-brca1
Entry 5 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-anforderung-trurisk-panel
Resource ServiceRequest:
Language: de
Profile: MII PR MolGen Anforderung genetischer Test version: 2027.0.0-ballot.1
identifier:
https://www.charite.de/fhir/auftragsnummern/gen_test_03status: Active
intent: Order
category: Laboratory procedure (procedure)
code: No display for ServiceRequest.code (concept: Molecular genetic test (procedure))
subject: Elisa Schmidt-Huber (official) Female, DoB: 1973-03-12 ( Medical record number (use: usual, ))
authoredOn: 2022-11-01
requester: Practitioner Dr. Linda Rubens(official)
Request:
PUT ServiceRequest/mii-exa-molgen-anforderung-trurisk-panel
Entry 6 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-practitioner-lab
Resource Practitioner:
Language: de
active: true
name: Dr. Daniel Schmidt(Official)
Request:
PUT Practitioner/mii-exa-molgen-practitioner-lab
Entry 7 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-practitioner-physician
Resource Practitioner:
Language: de
active: true
name: Dr. Linda Rubens(Official)
Request:
PUT Practitioner/mii-exa-molgen-practitioner-physician
Entry 8 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-specimen-brca1
Resource Specimen:
Language: de
identifier:
https://www.charite.de/fhir/sid/bioproben/specimen_03status: Available
type: Tissue specimen from breast (specimen)
subject: Elisa Schmidt-Huber (official) Female, DoB: 1973-03-12 ( Medical record number (use: usual, ))
receivedTime: 2022-11-01
Collections
Collected[x] 2022-11-01
Request:
PUT Specimen/mii-exa-molgen-specimen-brca1
Entry 9 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-device-sequencer-nextseq
Resource Device:
Language: de
status: Active
manufacturer: Illumina
Request:
PUT Device/mii-exa-molgen-device-sequencer-nextseq
Entry 10 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-variante-brca1
Resource Observation:
Language: de
Profiles: MII PR MolGen Variante version: 2027.0.0-ballot.1, Variant version: 3.0.0
basedOn: ServiceRequest Molecular genetic test (procedure)
status: Final
category: Laboratory, Genetics
code: Genetic variant assessment
subject: Elisa Schmidt-Huber (official) Female, DoB: 1973-03-12 ( Medical record number (use: usual, ))
effective: 2022-11-01
value: Present
method: Sequencing
device: Device: status = active; manufacturer = Illumina
component
code: Gene studied [ID]
value: BRCA1
component
code: Cytogenetic (chromosome) location
value: 17q21.31
component
code: DNA change (c.HGVS)
value: NM_007294.3:c.5266dupC
component
code: Transcript reference sequence [ID]
value: NM_007294.3
component
code: DNA change type
value: Duplication
component
code: Allelic read depth
value: 50 Abdeckung der Fragmente (Details: UCUM code1 = '1')
component
code: Discrete genetic variant
value: rs80357906
component
code: Chromosome [Identifier] in Blood or Tissue by Molecular genetics method
value: Chromosome 17
component
code: Amino acid change (pHGVS)
value: p.Gln1756Profs
component
code: Laboratory device Detection limit
value: >95 % (Details: UCUM code% = '%')
Request:
PUT Observation/mii-exa-molgen-variante-brca1
Entry 11 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-diagnostische-implikation-brca1
Resource Observation:
Language: de
Profiles: MII PR MolGen Diagnostische Implikation version: 2027.0.0-ballot.1, Diagnostic Implication version: 3.0.0
status: Final
category: Laboratory, Genetics
code: Diagnostic Implication
subject: Elisa Schmidt-Huber (official) Female, DoB: 1973-03-12 ( Medical record number (use: usual, ))
effective: 2022-11-01
performer: Practitioner Dr. Daniel Schmidt(official)
derivedFrom: Observation Genetic variant assessment
component
code: Conclusion Text
value: Nachweis heterozygoter Sequenzveränderung, die zum Funktionsverlust führt
component
code: Genetic variation clinical significance [Imp]
value: Pathogenic
component
code: Associated phenotype
value: Breast carcinoma
component
code: Level of evidence
value: 2 star
Request:
PUT Observation/mii-exa-molgen-diagnostische-implikation-brca1